pub struct TwoPhaseSet<X: Clone + Eq + Hash> {
pub added: HashSet<X>,
pub removed: HashSet<X>,
}Expand description
A set that can add or delete values
Panics
Any attempt to del an element that one did not previously add will panic:
ⓘ
// this will panic
use std::collections::HashSet;
use cvrdt_exposition::{Grow, Shrink, TwoPhaseSet};
let mut x = TwoPhaseSet::new((HashSet::new(), HashSet::new()));
x.del("this will panic");Examples
Example usage, including demonstrating some properties:
use std::collections::HashSet;
use cvrdt_exposition::{Grow, Shrink, TwoPhaseSet};
let mut x = TwoPhaseSet::new((HashSet::new(), HashSet::new()));
for c in "abc".chars() {
x.add(c);
}
x.del('c');
assert_eq!(x.query(&'a'), true);
assert_eq!(x.query(&'z'), false);
assert_eq!(x.query(&'c'), false);
let y = TwoPhaseSet::new(("abcdef".chars().collect(), HashSet::new()));
assert_eq!(x.merge(&y).payload(), y.merge(&x).payload());
let z = TwoPhaseSet::new(("8675309abcdefg".chars().collect(), "toremove".chars().collect()));
assert_eq!(x.merge(&y.merge(&z)).payload(), x.merge(&y).merge(&z).payload());Fields
added: HashSet<X>The elements that have been added to this set
removed: HashSet<X>The elements that have been removed from this set